@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:REFECO';    # AUTHORITY
-our $VERSION   = '0.002';          # VERSION
+our $VERSION   = '0.003';          # VERSION
 
 use Moose 2.2206;
 use namespace::clean;
@@ -90,7 +90,7 @@ Dist::Zilla::PluginBundle::Author::REFECO - REFECO dists defaults
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 OVERVIEW
 
@@ -111,6 +111,8 @@ Reproducible by the following dist.ini config:
     include_dotfiles = 1
 
     [PruneCruft]
+    exclude = .perlcriticrc
+    exclude = .perltidyrc
 
     [CopyFilesFromBuild]
     copy = Makefile.PL
